==> jc-1.4.0.tar.gz: javax/swing/border/SoftBevelBorder.h <==
// public class javax.swing.border.SoftBevelBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 841e9def39bee722 javax_swing_border_BevelBorder
// @dep_class bfab1b51c59d84c2 javax_swing_border_SoftBevelBorder

// header file dependencies
// @dep_header javax_swing_border_BevelBorder

#include "javax/swing/border/BevelBorder.h"

#ifndef _JC_javax_swing_border_SoftBevelBorder_H_
#define _JC_javax_swing_border_SoftBevelBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_border_SoftBevelBorder$sub_refs	_jc_javax_swing_border_SoftBevelBorder$sub_refs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$sub_nonrefs	_jc_javax_swing_border_SoftBevelBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$refs	_jc_javax_swing_border_SoftBevelBorder$refs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$nonrefs	_jc_javax_swing_border_SoftBevelBorder$nonrefs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$object	_jc_javax_swing_border_SoftBevelBorder$object;

typedef struct _jc_javax_swing_border_SoftBevelBorder$fields_struct	_jc_javax_swing_border_SoftBevelBorder$fields_struct;
typedef const struct _jc_javax_swing_border_SoftBevelBorder$vmethods	_jc_javax_swing_border_SoftBevelBorder$vmethods;
typedef const struct _jc_javax_swing_border_SoftBevelBorder$vtable	_jc_javax_swing_border_SoftBevelBorder$vtable;
typedef const struct _jc_javax_swing_border_SoftBevelBorder$vtype	_jc_javax_swing_border_SoftBevelBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_SoftBevelBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_SoftBevelBorder$fields_struct _jc_javax_swing_border_SoftBevelBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_SoftBevelBorder$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, jint);
extern void _jc_javax_swing_border_SoftBevelBorder$method$_init$41d172494a98484a(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);
extern void _jc_javax_swing_border_SoftBevelBorder$method$_init$5dd8ed0013db12ce(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_SoftBevelBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_SoftBevelBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
extern jboolean _jc_javax_swing_border_SoftBevelBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *);
extern void _jc_javax_swing_border_SoftBevelBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$paintBorder$4a79b2eae89db578;

// Static methods
extern void _jc_javax_swing_border_SoftBevelBorder$method$paintSoftBevel$95cab9be5f98576c(_jc_env *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods structure
struct _jc_javax_swing_border_SoftBevelBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_border_SoftBevelBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_BevelBorder$vmethods	javax_swing_border_BevelBorder;
	_jc_javax_swing_border_SoftBevelBorder$vmethods	javax_swing_border_SoftBevelBorder;
};

// Vtype
struct _jc_javax_swing_border_SoftBevelBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_SoftBevelBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_SoftBevelBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_border_SoftBevelBorder$refs {
    _jc_javax_swing_border_SoftBevelBorder$sub_refs	javax_swing_border_SoftBevelBorder;
    _jc_javax_swing_border_BevelBorder$sub_refs	javax_swing_border_BevelBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_SoftBevelBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_SoftBevelBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_BevelBorder$sub_nonrefs	javax_swing_border_BevelBorder;
    _jc_javax_swing_border_SoftBevelBorder$sub_nonrefs	javax_swing_border_SoftBevelBorder;
};

// Object instance structure
struct _jc_javax_swing_border_SoftBevelBorder$object {
	_jc_javax_swing_border_SoftBevelBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_SoftBevelBorder$vtype	*vtype;
	_jc_javax_swing_border_SoftBevelBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_SoftBevelBorder$vtype _jc_javax_swing_border_SoftBevelBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_SoftBevelBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_SoftBevelBorder$class_object;

#endif	/* _JC_javax_swing_border_SoftBevelBorder_H_ */

==> jc-1.4.6.tar.gz: javax/swing/border/SoftBevelBorder.h <==
// public class javax.swing.border.SoftBevelBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 841e9def39bee722 javax_swing_border_BevelBorder
// @dep_class bfab1b51c59d84c2 javax_swing_border_SoftBevelBorder

// header file dependencies
// @dep_header javax_swing_border_BevelBorder

#include "javax/swing/border/BevelBorder.h"

#ifndef _JC_javax_swing_border_SoftBevelBorder_H_
#define _JC_javax_swing_border_SoftBevelBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_border_SoftBevelBorder$sub_refs	_jc_javax_swing_border_SoftBevelBorder$sub_refs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$sub_nonrefs	_jc_javax_swing_border_SoftBevelBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$refs	_jc_javax_swing_border_SoftBevelBorder$refs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$nonrefs	_jc_javax_swing_border_SoftBevelBorder$nonrefs;
typedef struct _jc_javax_swing_border_SoftBevelBorder$object	_jc_javax_swing_border_SoftBevelBorder$object;

typedef struct _jc_javax_swing_border_SoftBevelBorder$fields_struct	_jc_javax_swing_border_SoftBevelBorder$fields_struct;
typedef const struct _jc_javax_swing_border_SoftBevelBorder$vmethods	_jc_javax_swing_border_SoftBevelBorder$vmethods;
typedef const struct _jc_javax_swing_border_SoftBevelBorder$vtable	_jc_javax_swing_border_SoftBevelBorder$vtable;
typedef const struct _jc_javax_swing_border_SoftBevelBorder$vtype	_jc_javax_swing_border_SoftBevelBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_SoftBevelBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_SoftBevelBorder$fields_struct _jc_javax_swing_border_SoftBevelBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_SoftBevelBorder$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_SoftBevelBorder$method$_init$41d172494a98484a(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_SoftBevelBorder$method$_init$5dd8ed0013db12ce(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_SoftBevelBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_SoftBevelBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_border_SoftBevelBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_SoftBevelBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_SoftBevelBorder$method_info$paintBorder$4a79b2eae89db578;

// Static methods
extern void _jc_javax_swing_border_SoftBevelBorder$method$paintSoftBevel$95cab9be5f98576c(_jc_env *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_border_SoftBevelBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_SoftBevelBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_border_SoftBevelBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_BevelBorder$vmethods	javax_swing_border_BevelBorder;
	_jc_javax_swing_border_SoftBevelBorder$vmethods	javax_swing_border_SoftBevelBorder;
};

// Vtype
struct _jc_javax_swing_border_SoftBevelBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_SoftBevelBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_SoftBevelBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_border_SoftBevelBorder$refs {
    _jc_javax_swing_border_SoftBevelBorder$sub_refs	javax_swing_border_SoftBevelBorder;
    _jc_javax_swing_border_BevelBorder$sub_refs	javax_swing_border_BevelBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_SoftBevelBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_SoftBevelBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_BevelBorder$sub_nonrefs	javax_swing_border_BevelBorder;
    _jc_javax_swing_border_SoftBevelBorder$sub_nonrefs	javax_swing_border_SoftBevelBorder;
};

// Object instance structure
struct _jc_javax_swing_border_SoftBevelBorder$object {
	_jc_javax_swing_border_SoftBevelBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_SoftBevelBorder$vtype	*vtype;
	_jc_javax_swing_border_SoftBevelBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_SoftBevelBorder$vtype _jc_javax_swing_border_SoftBevelBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_SoftBevelBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_SoftBevelBorder$class_object;

#endif	/* _JC_javax_swing_border_SoftBevelBorder_H_ */
